@@ -10,7 +10,7 @@ from knack.util import CLIError
 from azext_devops.devops_sdk.exceptions import AzureDevOpsClientRequestError
 from azext_devops.devops_sdk.v5_0.git.models import (GitPullRequest, GitPullRequestCompletionOptions,
                                                      GitPullRequestSearchCriteria, IdentityRef, IdentityRefWithVote,
-                                                     ResourceRef, GitRefFavorite)
+                                                     ResourceRef, GitRefFavorite, WebApiTagDefinition)
 from azext_devops.devops_sdk.v5_0.work_item_tracking.models import JsonPatchOperation, WorkItemRelation
 from azext_devops.dev.common.arguments import should_detect
 from azext_devops.dev.common.git import get_current_branch_name, resolve_git_ref_heads, fetch_remote_and_checkout
@@ -95,12 +95,13 @@ def list_pull_requests(repository=None, creator=None, include_links=False, revie
     return pr_list
 
 
-# pylint: disable=too-many-locals
+# pylint: disable=too-many-statements, too-many-locals, redefined-builtin
 def create_pull_request(project=None, repository=None, source_branch=None, target_branch=None,
                         title=None, description=None, auto_complete=False, squash=False,
                         delete_source_branch=False, bypass_policy=False, bypass_policy_reason=None,
-                        merge_commit_message=None, reviewers=None, work_items=None, draft=None,
-                        open=False, organization=None, detect=None, transition_work_items=False):  # pylint: disable=redefined-builtin
+                        merge_commit_message=None, optional_reviewers=None, required_reviewers=None,
+                        work_items=None, draft=None, open=False, organization=None, detect=None,
+                        transition_work_items=False, labels=None):  # pylint: disable=redefined-builtin
     """Create a pull request.
     :param project: Name or ID of the team project.
     :type project: str
@@ -134,9 +135,12 @@ def create_pull_request(project=None, repository=None, source_branch=None, targe
     :type bypass_policy_reason: str
     :param merge_commit_message: Message displayed when commits are merged.
     :type merge_commit_message: str
-    :param reviewers: Additional users or groups to include as reviewers on the new pull request.
+    :param optional_reviewers: Additional users or groups to include as optional reviewers on the new pull request.
                       Space separated.
-    :type reviewers: list of str
+    :type optional_reviewers: list of str
+    :param required_reviewers: Additional users or groups to include as required reviewers on the new pull request.
+                      Space separated.
+    :type required_reviewers: list of str
     :param work_items: IDs of the work items to link to the new pull request. Space separated.
     :type work_items: list of str
     :param open: Open the pull request in your web browser.
@@ -144,6 +148,8 @@ def create_pull_request(project=None, repository=None, source_branch=None, targe
     :param transition_work_items: Transition any work items linked to the pull request into the next logical state.
                    (e.g. Active -> Resolved)
     :type transition_work_items: bool
+    :param labels: The labels associated with the pull request. Space separated.
+    :type labels: list of str
     :rtype: :class:`GitPullRequest <v5_0.git.models.GitPullRequest>`
     """
     organization, project, repository = resolve_instance_project_and_repo(
@@ -157,22 +163,35 @@ def create_pull_request(project=None, repository=None, source_branch=None, targe
     multi_line_description = None
     if description is not None:
         multi_line_description = '\n'.join(description)
-    pr = GitPullRequest(description=multi_line_description, source_ref_name=source_branch,
-                        target_ref_name=target_branch)
+    if labels is not None:
+        labels = [WebApiTagDefinition(name=label) for label in labels.split(' ')]
+    pr = GitPullRequest(description=multi_line_description,
+                        source_ref_name=source_branch,
+                        target_ref_name=target_branch,
+                        labels=labels)
     if draft is not None:
         pr.is_draft = draft
+
+    pr.title = 'Merge ' + source_branch + ' to ' + target_branch
     if title is not None:
         pr.title = title
-    else:
-        pr.title = 'Merge ' + source_branch + ' to ' + target_branch
+
     pr.source_ref_name = resolve_git_ref_heads(source_branch)
     pr.target_ref_name = resolve_git_ref_heads(target_branch)
     if pr.source_ref_name == pr.target_ref_name:
         raise CLIError('The source branch, "{}", can not be the same as the target branch.'.format
                        (pr.source_ref_name))
-    if reviewers is not None:
-        reviewers = list(set(x.lower() for x in reviewers))
-    pr.reviewers = _resolve_reviewers_as_refs(reviewers, organization)
+
+    if optional_reviewers is not None:
+        optional_reviewers = list(set(x.lower() for x in optional_reviewers))
+
+    if required_reviewers is not None:
+        required_reviewers = list(set(x.lower() for x in required_reviewers))
+
+    reviewers = _resolve_reviewers_as_refs(optional_reviewers, required_reviewers, organization)
+
+    pr.reviewers = reviewers
+
     if work_items is not None and work_items:
         resolved_work_items = []
         for work_item in work_items:
@@ -180,20 +199,34 @@ def create_pull_request(project=None, repository=None, source_branch=None, targe
         pr.work_item_refs = resolved_work_items
     pr = client.create_pull_request(git_pull_request_to_create=pr, project=project,
                                     repository_id=repository)
+    # if title or description are not provided and there is a single commit, we will
+    # use the its comment to populate the not-provided field(s).
+    # the first line of the commit comment is used for title and all lines of the
+    # comment are used for description.
     title_from_commit = None
-    if title is None:
-        # if title wasn't specified and only one commit, we will set the PR title to the comment of that commit
+    description_from_commit = None
+    if (title is None) or (description is None):
         commits = client.get_pull_request_commits(repository_id=repository, pull_request_id=pr.pull_request_id,
                                                   project=project)
         if len(commits) == 1:
-            title_from_commit = commits[0].comment
+            commit_details = client.get_commit(commit_id=commits[0].commit_id, repository_id=repository,
+                                               project=project, change_count=0)
+            first_commit_comment = commit_details.comment
+
+            if first_commit_comment:
+                # when title is not specified, use the first line of first commit comment as PR title
+                if title is None:
+                    title_from_commit = first_commit_comment.split("\n")[0]
+                # when description is not specified, use the entire commit comment as PR description
+                if description is None:
+                    description_from_commit = first_commit_comment
     set_completion_options = (bypass_policy or
                               bypass_policy_reason is not None or
                               squash or
                               merge_commit_message is not None or
                               delete_source_branch or
                               transition_work_items)
-    if auto_complete or set_completion_options or title_from_commit is not None:
+    if auto_complete or set_completion_options or title_from_commit is not None or description_from_commit is not None:
         pr_for_update = GitPullRequest()
         if auto_complete:
             # auto-complete will not get set on create, so a subsequent update is required.
@@ -209,6 +242,8 @@ def create_pull_request(project=None, repository=None, source_branch=None, targe
             pr_for_update.completion_options = completion_options
         if title_from_commit is not None:
             pr_for_update.title = title_from_commit
+        if description_from_commit is not None:
+            pr_for_update.description = description_from_commit
         pr = client.update_pull_request(git_pull_request_to_update=pr_for_update,
                                         project=pr.repository.project.id,
                                         repository_id=pr.repository.id,
@@ -323,18 +358,25 @@ def update_pull_request(id, title=None, description=None, auto_complete=None,  #
     return pr
 
 
-def create_pull_request_reviewers(id, reviewers, organization=None, detect=None):  # pylint: disable=redefined-builtin
+def create_pull_request_reviewers(id, reviewers, organization=None, detect=None, required=None):  # pylint: disable=redefined-builtin
     """Add one or more reviewers to a pull request.
     :param id: ID of the pull request.
     :type id: int
     :param reviewers: Users or groups to include as reviewers on a pull request. Space separated.
     :type reviewers: list of str
+    :param required: Make the reviewers required.
+    :type reviewers: bool
     :rtype: list of :class:`IdentityRefWithVote <v5_0.git.models.IdentityRefWithVote>`
     """
     organization = resolve_instance(detect=detect, organization=organization)
     client = get_git_client(organization)
     pr = client.get_pull_request_by_id(id)
-    resolved_reviewers = _resolve_reviewers_as_refs(reviewers, organization)
+    resolved_reviewers = _resolve_reviewers_as_refs(reviewers, None, organization)
+
+    if required:
+        for reviewer in resolved_reviewers:
+            reviewer.is_required = True
+
     identities = client.create_pull_request_reviewers(reviewers=resolved_reviewers,
                                                       project=pr.repository.project.id,
                                                       repository_id=pr.repository.id,
@@ -593,16 +635,34 @@ def queue_pr_policy(id, evaluation_id, organization=None, detect=None):  # pylin
                                                    evaluation_id=evaluation_id)
 
 
-def _resolve_reviewers_as_refs(reviewers, organization):
+def _resolve_reviewers_as_refs(optional_reviewers, required_reviewers, organization):
     """Takes a list containing identity names, emails, and ids,
-    and return a list of IdentityRefWithVote objects.
+    and return a list of IdentityRefWithVote objects. Reviewers found twice will be made required
+    :param optional_reviewers: the list of optional reviewers
+    :param required_reviewers: the list of required reviewers
     :rtype: list of :class:`IdentityRefWithVote <v5_0.git.models.IdentityRefWithVote>`
     """
-    resolved_reviewers = None
-    if reviewers is not None and reviewers:
-        resolved_reviewers = []
-        for reviewer in reviewers:
-            resolved_reviewers.append(IdentityRefWithVote(id=resolve_identity_as_id(reviewer, organization)))
+    if optional_reviewers is None:
+        optional_reviewers = []
+    if required_reviewers is None:
+        required_reviewers = []
+    resolved_reviewers = []
+
+    for reviewer in optional_reviewers:
+        resolved_reviewers.append(IdentityRefWithVote(id=resolve_identity_as_id(reviewer, organization)))
+
+    for reviewer in required_reviewers:
+        resolved_reviewer = IdentityRefWithVote(id=resolve_identity_as_id(reviewer, organization))
+
+        # is this id already in the list (make duplicate required)
+        for optional_reviewer in resolved_reviewers:
+            if optional_reviewer.id == resolved_reviewer.id:
+                optional_reviewer.is_required = True
+                continue
+
+        resolved_reviewer.is_required = True
+        resolved_reviewers.append(resolved_reviewer)
+
     return resolved_reviewers
 
 
