@@ -18,9 +18,7 @@ NAME = 'azure-devops'
 # http://pypi.python.org/pypi/setuptools
 
 REQUIRES = [
-    'distro==1.3.0',
-    'python-dateutil==2.7.3',
-    'msrest>=0.6.0,<0.7.0'
+    'distro==1.3.0'
 ]
 
 # Version extraction inspired from 'requests'
