@@ -10,7 +10,7 @@ from azure_devtools.scenario_tests import AllowLargeResponse
 from .utilities.helper import (
     DevopsScenarioTest, get_random_name, disable_telemetry, set_authentication, get_test_org_from_env_variable)
 
-DEVOPS_CLI_TEST_ORGANIZATION = get_test_org_from_env_variable() or 'Https://dev.azure.com/devops-cli-test-org'
+DEVOPS_CLI_TEST_ORGANIZATION = get_test_org_from_env_variable() or 'Https://dev.azure.com/v-anvashist0376'
 
 class ReposRepoTests(DevopsScenarioTest):
     @AllowLargeResponse(size_kb=3072)
